@@ -1,24 +1,15 @@
 import os
-import glob
 import xml.etree.ElementTree as ET
+from typing import Any, Dict
 
-from firstimpression.constants import APIS, TEMP_FOLDER, DUTCH_INDEX, LOCAL_INTEGRATED_FOLDER
-from firstimpression.file import update_directories_api, check_too_old, download_install_media, write_root_to_xml_files
-from firstimpression.time import parse_string_to_string, change_language
-from firstimpression.scala import variables, Log
+from firstimpression.api.request import give_error_message, request_json
+from firstimpression.constants import APIS
+from firstimpression.file import (check_too_old, create_directories,
+                                  purge_directories)
+from firstimpression.placeholder import update_placeholders
+from firstimpression.scala import ScalaPlayer
 from firstimpression.text import remove_emoji
-from firstimpression.api.request import request_json
-
-##################################################################################################
-# LOGGING
-##################################################################################################
-
-script = 'Facebook'
-
-info = Log('INFO', script)
-debug = Log('DEBUG', script)
-warn = Log('WARN', script)
-error = Log('ERROR', script)
+from firstimpression.time import parse_string_to_string
 
 ##################################################################################################
 # CONSTANTS
@@ -34,17 +25,29 @@ BASE_URL_IMAGES = 'https://socials-bucket.s3.eu-central-1.amazonaws.com'
 
 XML_FILENAME = 'facebook.xml'
 
+##################################################################################################
+# LOGGING
+##################################################################################################
+
+scala = ScalaPlayer(NAME)
+
+XML_TEMP_PATH = os.path.join(scala.temp_folder, XML_FILENAME)
 
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
-def run_api(api_key, max_minutes, max_characters, max_items):
-    debug.log('folder name: {}'.format(NAME))
-    max_file_age = 60 * max_minutes
-    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
-    
-    debug.log('max_file_age: {} - temp path: {}'.format(max_file_age, xml_temp_path))
+
+def run_api():
+    scala.debug('folder name: {}'.format(NAME))
+
+    max_file_age = 60 * scala.variables['max_minutes']
+    api_key = scala.variables['api_key']
+    max_characters = scala.variables['max_chars']
+    max_items = scala.variables['max_items']
+
+    scala.debug(
+        'max_file_age: {} - temp path: {}'.format(max_file_age, XML_TEMP_PATH))
 
     headers = {
         'Authorization': 'Token {}'.format(api_key)
@@ -54,67 +57,69 @@ def run_api(api_key, max_minutes, max_characters, max_items):
         'number_of_posts': max_items
     }
 
-    update_directories_api(NAME)
-    change_language(DUTCH_INDEX)
+    create_directories([scala.temp_folder, scala.content_folder])
+    purge_directories([scala.temp_folder, scala.content_folder], max_days=1)
+    update_placeholders()
 
-    if check_too_old(xml_temp_path, max_file_age):
+    if check_too_old(XML_TEMP_PATH, max_file_age):
         response_json, is_error = request_json(URL, headers, params, False)
 
         if is_error:
+            message = give_error_message(response_json)
             if response_json['type'] == 'ERROR':
-                error.log('request {} -> {}'.format(response_json['reason'], response_json['message']))
+                scala.error(message)
             elif response_json['type'] == 'WARN':
-                warn.log('request {} -> {}'.format(response_json['reason'], response_json['message']))
-            exit()
+                scala.warn(message)
+
+            raise SystemExit
+        else:
+            response_json: Any
 
         root = ET.Element("root")
 
         for post in response_json:
             item = ET.SubElement(root, "item")
-            ET.SubElement(item, "likes").text = str(get_reactions(post)['likes'])
-            ET.SubElement(item, "message").text = crop_message(remove_emoji(get_message(post)), max_characters)
-            ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, DATETIME_FORMAT_NEW)
+            ET.SubElement(item, "likes").text = str(
+                get_reactions(post)['likes'])
+            ET.SubElement(item, "message").text = crop_message(
+                remove_emoji(get_message(post)), max_characters)
+            ET.SubElement(item, "created_time").text = parse_string_to_string(
+                get_creation_date(post), DATETIME_FORMAT, DATETIME_FORMAT_NEW)
 
             thumbnail_url = get_image(post)
             if thumbnail_url is None:
-                debug.log('image not found using placeholder')
+                scala.debug('image not found using placeholder')
                 media_link = 'Content:\\placeholders\\img.png'
             else:
-                debug.log(thumbnail_url)
-                media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME)
-            
+                scala.debug(thumbnail_url)
+                temp_path = scala.download_media_temp(thumbnail_url)
+                media_link = scala.install_content(temp_path)
+
             ET.SubElement(item, "image").text = media_link
 
-        write_root_to_xml_files(root, xml_temp_path, NAME)        
+        temp_path = scala.download_root_temp(root, XML_FILENAME)
+        scala.install_content(temp_path)
     else:
-        debug.log('File not old enough to download new info')
+        scala.debug('File not old enough to download new info')
 
-def check_api(max_minutes):
-    svars = variables()
 
-    max_file_age = 60 * max_minutes + 2
+def check_api():
+    svars = scala.variables
 
-    debug.log('max_file_age: {}'.format(max_file_age))
+    max_file_age = 60 * svars['max_minutes'] + 2
 
-    file_name = 'facebook*.xml'
-    file_path = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, file_name)
+    scala.debug('max_file_age: {}'.format(max_file_age))
 
-    debug.log('local path: {}'.format(file_path))
+    file_path = scala.find_content(
+        'Content://{}/{}'.format(NAME, XML_FILENAME))
 
-    file_path = sorted(glob.glob(file_path))
+    scala.debug('local path: {}'.format(file_path))
 
-    if len(file_path) > 0:
-        file_path = file_path[-1]
-        debug.log('glob filepath: {}'.format(file_path))
-
-        if check_too_old(file_path, max_file_age):
-            svars['skipscript'] = True
-            info.log('file too old')
-        else:
-            svars['skipscript'] = False
-    else:
-        warn.log('File does not exists')
+    if check_too_old(file_path, max_file_age):
         svars['skipscript'] = True
+        scala.debug('file too old')
+    else:
+        svars['skipscript'] = False
 
 ##################################################################################################
 # MEDIA FUNCTIONS
@@ -125,27 +130,31 @@ def check_api(max_minutes):
 # GET FUNCTIONS
 ##################################################################################################
 
-def get_image(post):
+def get_image(post: Dict[str, Any]):
     return post.get('image', None)
 
-def get_reactions(post):
+
+def get_reactions(post: Dict[str, Any]):
     return post.get('reactions', {})
 
-def get_message(post):
+
+def get_message(post: Dict[str, Any]):
     return post.get('message', '')
 
-def get_creation_date(post):
+
+def get_creation_date(post: Dict[str, Any]):
     creation_date = post.get('created_at', None)
     if creation_date is None:
-        return None
+        return ''
     else:
-        return creation_date[:19]
+        return str(creation_date[:19])
 
 ##################################################################################################
 # PARSE FUNCTIONS
 ##################################################################################################
 
-def crop_message(text, max_length):
+
+def crop_message(text: str, max_length: int):
     if len(text) > max_length:
         return text[:max_length-3] + "...\nLees verder op Facebook"
     else:
