@@ -32,6 +32,7 @@ class ScalaPlayer:
     _debug_field = 'Player.debug_python'
     _language_field = 'Player.language'
     _fi_api_field = 'Player.fi_api_key'
+    _player_uuid_field = 'Player.uuid'
 
     _find_me_filename = 'find_me.txt'
     _find_me_path = os.path.join(gettempdir(), _find_me_filename)
@@ -56,6 +57,7 @@ class ScalaPlayer:
         self.is_debug = self._get_debug()
         self.language = self._get_language()
         self.fi_api_key = self._get_fi_key()
+        self.uuid = self._get_player_uuid()
         self._change_language()
 
         self.variables = self.Variables(self)
@@ -218,6 +220,10 @@ class ScalaPlayer:
         fi_api_key = self._get_value(self._fi_api_field)
         return '' if fi_api_key is None else fi_api_key
 
+    def _get_player_uuid(self) -> str:
+        uuid = self._get_value(self._player_uuid_field)
+        return '' if uuid is None else uuid
+
     def _get_keys(self) -> KeysView[str]:
         if not self.is_main:
             return self._scalaplayer.ListScalaScriptValues()
